@@ -7,6 +7,7 @@ from simple_gl.groups import Groups
 from simple_gl.hooks import Hooks
 from simple_gl.branches import Branches
 from simple_gl.commits import Commits
+from simple_gl.merge_request import MergeRequests
 
 
 class GLObject:
@@ -16,3 +17,4 @@ class GLObject:
         self.hooks = Hooks(url, private_token)
         self.branches = Branches(url, private_token)
         self.commits = Commits(url, private_token)
+        self.merge_requests = MergeRequests(url, private_token)
