@@ -12,6 +12,6 @@ class GitLabBase:
 
 
 class MergeRequestResponse(BaseModel):
-    status: str = "0"
+    status: int = 0
     message: str = ""
     navigateTo: str = ""
